
function [out] = read_spice_results(filename)
  ff = mopen(filename);
  foo = mgetl(ff,4);  // skip first lines
  [foo, foo, foo, varnum] = mfscanf(ff,"%s %s %d"); 
  [foo, foo, foo, tnum] = mfscanf(ff,"%s %s %d");  
  foo = mgetl(ff,6);  // skip lines
  
  formatstring = "%s";
  for i=1:1:varnum
    formatstring = formatstring + "%f\n";
  end
     
  out = mfscanf(tnum, ff, formatstring);
  
  mclose(ff);  
endfunction

function [] = change_spice_parameter(command_file, spice_change_params)
  
  try
    infile = mopen(command_file, "r");
    s = mgetl(infile, -1);
    mclose(infile);
  catch
    error("Error reading file """ + command_file+""""); 
  end
  try
  outfile = mopen(command_file+".mscn", "w");
  catch
    error("Error writing to file """ + command_file+".mscn""");
  end
  
  for i=1:1:max(size(s))
    
    if (strindex(s(i), "alter") ~= 1) mfprintf(outfile, s(i)+"\n");  end;    
    
    if (i==3)
      try  
      for j=1:1:size(spice_change_params(1), 1)
        ss = sprintf("alter %s [ ", spice_change_params(1)(j) );        
        ss = ss + sprintf(" %s ", spice_change_params(j+1) );
        ss = ss + "]";         
        mfprintf(outfile, ss+"\n");       
      end
      catch
        mclose(outfile);
        error("Error evaluating ngspice data change list supplied from your model.");
      end
    end
    
  end
  mclose(outfile);
  
endfunction

function ver = check_ngspice_ver()
  if (unix("ngspice --version") ~= 0) 
    ver = -1;
    return;
  end
  
  a = unix_g("ngspice --version");
  
  ver = "0";
  for i=1:1:size(a,1)
    x = strindex(a(i), "revision");  
    
    if (length(x) > 0)
      ver = part(a(1), x+9:x+10);  
    end
  end
  
  try
    execstr("ver = "+ver);
  catch
    ver = 0;
  end 
endfunction 


function [] = call_ngspice(netlist, command_file)
  
  if (ngspice_version) < 20
    error("ngspice-20 or newer not found on your system, you are not able to run the model.");    
  end
  
  ret = unix_g("ngspice " + netlist + " -i " + command_file+".mscn");
  print_all = 0;
  for i=1:1:size(ret, 1)
    if ( (length(strindex(ret(i), "Error")) > 0) & (print_all == 0) )
      error_log_text ("215: Ngspice reported an error, output: ");
      print_all = 1;            
    end
    if (print_all == 1)
      log_text ("&nbsp &nbsp "+ret(i));
    end;
  end
  
  if (print_all == 1)
    error("ngspice returned an error, above messages were returned.");
  end
  

endfunction
